==> coupon-facade-1.0.3-20190322.063944-8-sources.jar: com/bizvane/couponfacade/models/vo/SendCouponSimpleOldVO.java <==
package com.bizvane.couponfacade.models.vo;

import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;

public class SendCouponSimpleOldVO implements Serializable {

    /**
     *
     */
    private static final long serialVersionUID = 1L;



    
    @ApiModelProperty(value = "erpid转-会员code", name = "memberCode", required = false, example = "")
    private String erpId;
    
    @ApiModelProperty(value = "线券定义code转-线上券定义id", name = "couponDefinitionId", required = false, example = "")
    private String erpCouponDefinitionCode;
    
    @ApiModelProperty(value = "券号", name = "券号", required = false, example = "")
    private String couponCode;
    
    @ApiModelProperty(value = "开始时间", name = "开始时间", required = false, example = "")
    private String startTime;
    
    @ApiModelProperty(value = "结束时间", name = "结束时间", required = false, example = "")
    private String endTime;
    
    @ApiModelProperty(value = "是否使用", name = "是否使用", required = false, example = "")
    private String isuse;
    @ApiModelProperty(value = "使用时间", name = "使用时间", required = false, example = "")
    private String useTime;
    
    @ApiModelProperty(value = "erpid转-会员code", name = "memberCode", required = false, example = "")
    private String memberCode;
    @ApiModelProperty(value = "线券定义cod转-线上券定义id", name = "couponDefinitionId", required = false, example = "")
    private Long couponDefinitionId;

    @ApiModelProperty(value = "发送类型", name = "sendType", required = false, example = "")
    private String sendType;

    @ApiModelProperty(value = "业务id", name = "sendBussienId", required = false, example = "")
    private Long sendBussienId;

    @ApiModelProperty(value = "任务名称", name = "businessName", required = false, example = "")
    private String businessName;
    
    
    
    
    @ApiModelProperty(value = "表格url", name = "表格url", required = false, example = "")
    private String url;
    
    @ApiModelProperty(value = "errMgs", name = "errMgs", required = false, example = "")
    private String errMgs;
    
    
    
    
	public String getUseTime() {
		return useTime;
	}

	public void setUseTime(String useTime) {
		this.useTime = useTime;
	}

	public String getStartTime() {
		return startTime;
	}

	public void setStartTime(String startTime) {
		this.startTime = startTime;
	}

	public String getEndTime() {
		return endTime;
	}

	public void setEndTime(String endTime) {
		this.endTime = endTime;
	}

	public String getIsuse() {
		return isuse;
	}

	public void setIsuse(String isuse) {
		this.isuse = isuse;
	}

	public SendCouponSimpleOldVO(String string, String string2, String string3, String string4, String string5, String string6, String string7) {
		this.erpId=string;
		this.erpCouponDefinitionCode=string2;
		this.couponCode=string3;
		this.startTime=string4;
		this.endTime=string5;
		this.isuse=string6;
		this.useTime=string7;
		
	}

	public String getErrMgs() {
		return errMgs;
	}

	public void setErrMgs(String errMgs) {
		this.errMgs = errMgs;
	}

	public String getUrl() {
		return url;
	}

	public void setUrl(String url) {
		this.url = url;
	}

	public String getCouponCode() {
		return couponCode;
	}

	public void setCouponCode(String couponCode) {
		this.couponCode = couponCode;
	}

	public String getMemberCode() {
		return memberCode;
	}

	public void setMemberCode(String memberCode) {
		this.memberCode = memberCode;
	}

	public String getErpId() {
		return erpId;
	}

	public void setErpId(String erpId) {
		this.erpId = erpId;
	}

	public Long getCouponDefinitionId() {
		return couponDefinitionId;
	}

	public void setCouponDefinitionId(Long couponDefinitionId) {
		this.couponDefinitionId = couponDefinitionId;
	}

	public String getErpCouponDefinitionCode() {
		return erpCouponDefinitionCode;
	}

	public void setErpCouponDefinitionCode(String erpCouponDefinitionCode) {
		this.erpCouponDefinitionCode = erpCouponDefinitionCode;
	}

	public String getSendType() {
		return sendType;
	}

	public void setSendType(String sendType) {
		this.sendType = sendType;
	}

	public Long getSendBussienId() {
		return sendBussienId;
	}

	public void setSendBussienId(Long sendBussienId) {
		this.sendBussienId = sendBussienId;
	}

	public String getBusinessName() {
		return businessName;
	}

	public void setBusinessName(String businessName) {
		this.businessName = businessName;
	}
    
    
    


}

==> coupon-facade-1.0.3-20190513.032407-11-sources.jar: com/bizvane/couponfacade/models/vo/SendCouponSimpleOldVO.java <==
package com.bizvane.couponfacade.models.vo;

import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;

public class SendCouponSimpleOldVO implements Serializable {

    /**
     *
     */
    private static final long serialVersionUID = 1L;



    
    @ApiModelProperty(value = "erpid转-会员code", name = "memberCode", required = false, example = "")
    private String erpId;
    
    @ApiModelProperty(value = "线券定义code转-线上券定义id", name = "couponDefinitionId", required = false, example = "")
    private String erpCouponDefinitionCode;
    
    @ApiModelProperty(value = "券号", name = "券号", required = false, example = "")
    private String couponCode;
    
    @ApiModelProperty(value = "开始时间", name = "开始时间", required = false, example = "")
    private String startTime;
    
    @ApiModelProperty(value = "结束时间", name = "结束时间", required = false, example = "")
    private String endTime;
    
    @ApiModelProperty(value = "是否使用", name = "是否使用", required = false, example = "")
    private String isuse;
    @ApiModelProperty(value = "使用时间", name = "使用时间", required = false, example = "")
    private String useTime;
    
    @ApiModelProperty(value = "erpid转-会员code", name = "memberCode", required = false, example = "")
    private String memberCode;
    @ApiModelProperty(value = "线券定义cod转-线上券定义id", name = "couponDefinitionId", required = false, example = "")
    private Long couponDefinitionId;

    @ApiModelProperty(value = "发送类型", name = "sendType", required = false, example = "")
    private String sendType;

    @ApiModelProperty(value = "业务id", name = "sendBussienId", required = false, example = "")
    private Long sendBussienId;

    @ApiModelProperty(value = "任务名称", name = "businessName", required = false, example = "")
    private String businessName;
    
    
    
    
    @ApiModelProperty(value = "表格url", name = "表格url", required = false, example = "")
    private String url;
    
    @ApiModelProperty(value = "errMgs", name = "errMgs", required = false, example = "")
    private String errMgs;
    
    
    
    
	public String getUseTime() {
		return useTime;
	}

	public void setUseTime(String useTime) {
		this.useTime = useTime;
	}

	public String getStartTime() {
		return startTime;
	}

	public void setStartTime(String startTime) {
		this.startTime = startTime;
	}

	public String getEndTime() {
		return endTime;
	}

	public void setEndTime(String endTime) {
		this.endTime = endTime;
	}

	public String getIsuse() {
		return isuse;
	}

	public void setIsuse(String isuse) {
		this.isuse = isuse;
	}

	public SendCouponSimpleOldVO(String string, String string2, String string3, String string4, String string5, String string6, String string7, String string8, String string9) {
		this.erpId=string;
		this.erpCouponDefinitionCode=string2;
		this.couponCode=string3;
		this.startTime=string4;
		this.endTime=string5;
		this.isuse=string6;
		this.useTime=string7;
		this.sendType=string8;
		this.businessName=string9;

	}

	public String getErrMgs() {
		return errMgs;
	}

	public void setErrMgs(String errMgs) {
		this.errMgs = errMgs;
	}

	public String getUrl() {
		return url;
	}

	public void setUrl(String url) {
		this.url = url;
	}

	public String getCouponCode() {
		return couponCode;
	}

	public void setCouponCode(String couponCode) {
		this.couponCode = couponCode;
	}

	public String getMemberCode() {
		return memberCode;
	}

	public void setMemberCode(String memberCode) {
		this.memberCode = memberCode;
	}

	public String getErpId() {
		return erpId;
	}

	public void setErpId(String erpId) {
		this.erpId = erpId;
	}

	public Long getCouponDefinitionId() {
		return couponDefinitionId;
	}

	public void setCouponDefinitionId(Long couponDefinitionId) {
		this.couponDefinitionId = couponDefinitionId;
	}

	public String getErpCouponDefinitionCode() {
		return erpCouponDefinitionCode;
	}

	public void setErpCouponDefinitionCode(String erpCouponDefinitionCode) {
		this.erpCouponDefinitionCode = erpCouponDefinitionCode;
	}

	public String getSendType() {
		return sendType;
	}

	public void setSendType(String sendType) {
		this.sendType = sendType;
	}

	public Long getSendBussienId() {
		return sendBussienId;
	}

	public void setSendBussienId(Long sendBussienId) {
		this.sendBussienId = sendBussienId;
	}

	public String getBusinessName() {
		return businessName;
	}

	public void setBusinessName(String businessName) {
		this.businessName = businessName;
	}
    
    
    


}
